Module from_csv

Module from_csv 

CSV to HEDL conversion. CSV to HEDL conversion

Structs

FromCsvConfig
Configuration for CSV parsing.

Constants

DEFAULT_MAX_CELL_SIZE
Default maximum cell size in bytes to prevent cell bomb attacks.
DEFAULT_MAX_COLUMNS
Default maximum number of columns to prevent column bomb attacks.
DEFAULT_MAX_HEADER_SIZE
Default maximum header size in bytes to prevent header bombs.
DEFAULT_MAX_ROWS
This limit prevents Denial-of-Service attacks from maliciously large CSV files. The default is 1 million rows, which allows processing reasonably large datasets while preventing unbounded memory allocation.
DEFAULT_MAX_TOTAL_SIZE
Default maximum total CSV size in bytes to prevent decompression bombs.

Functions

from_csv
Parse CSV string into a HEDL document with default configuration.
from_csv_reader
Parse CSV from a reader into a HEDL document with default configuration.
from_csv_reader_with_config
Converts a CSV file to a HEDL Document with custom configuration.
from_csv_with_config
Parse CSV string into a HEDL document with custom configuration.