CSV to HEDL conversion. CSV to HEDL conversion
Structs
- From
CsvConfig - Configuration for CSV parsing.
Constants
- DEFAULT_
MAX_ CELL_ SIZE - Default maximum cell size in bytes to prevent cell bomb attacks.
- DEFAULT_
MAX_ COLUMNS - Default maximum number of columns to prevent column bomb attacks.
- DEFAULT_
MAX_ HEADER_ SIZE - Default maximum header size in bytes to prevent header bombs.
- DEFAULT_
MAX_ ROWS - This limit prevents Denial-of-Service attacks from maliciously large CSV files. The default is 1 million rows, which allows processing reasonably large datasets while preventing unbounded memory allocation.
- DEFAULT_
MAX_ TOTAL_ SIZE - Default maximum total CSV size in bytes to prevent decompression bombs.
Functions
- from_
csv - Parse CSV string into a HEDL document with default configuration.
- from_
csv_ reader - Parse CSV from a reader into a HEDL document with default configuration.
- from_
csv_ reader_ with_ config - Converts a CSV file to a HEDL Document with custom configuration.
- from_
csv_ with_ config - Parse CSV string into a HEDL document with custom configuration.